@@ -123,7 +123,7 @@ class REST_CONFIG:
     JSON_FEATUREGROUP_ON_DEMAND_QUERY = "query"
     JSON_FEATUREGROUP_JDBC_CONNECTOR_NAME = "jdbcConnectorName"
     JSON_FEATUREGROUP_JDBC_CONNECTOR_ID = "jdbcConnectorId"
-    JSON_FEATUREGROUP_TYPE = "featuregroupType"
+    JSON_FEATUREGROUP_TYPE = "type"
     JSON_FEATUREGROUP_NAME = "name"
     JSON_FEATUREGROUP_ID = "id"
     JSON_FEATUREGROUP_VERSION = "version"
@@ -136,9 +136,8 @@ class REST_CONFIG:
     JSON_FEATUREGROUP_FEATURES_HISTOGRAM = "featuresHistogram"
     JSON_FEATUREGROUP_FEATURES_CLUSTERS = "clusterAnalysis"
     JSON_FEATUREGROUPS = "featuregroups"
-    JSON_FEATUREGROUP_INODE_ID = "inodeId"
-    JSON_FEATUREGROUP_ONLINE = "onlineFeaturegroupEnabled"
-    JSON_FEATUREGROUP_ONLINE_DTO = "onlineFeaturegroupDTO"
+    JSON_FEATUREGROUP_ONLINE = "onlineEnabled"
+    JSON_FEATUREGROUP_HUDI = "hudiEnabled"
 
     JSON_ONLINE_FEATUREGROUP_ID = "id"
     JSON_ONLINE_FEATUREGROUP_DB = "dbName"
