@@ -24,4 +24,4 @@ class TrainingDataset(FeaturestoreEntity):
         self.version = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_VERSION]
         self.data_format = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_FORMAT]
         self.training_dataset_type = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_TYPE]
-        self.location = training_dataset_json[constants.JSON_TRAINING_DATASET_LOCATION]
\ No newline at end of file
+        self.location = training_dataset_json[constants.REST_CONFIG.JSON_TRAINING_DATASET_LOCATION]
